import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  // 基本信息
  brandName: z.string().describe('品牌名称'),
  employeeCode: z.string().describe('员工个人码'),
});

// 生成邮件模板
const generateEmailTemplate = (
  brandName: string,
  employeeCode: string,
): string => `
  <!DOCTYPE html>
  <html>
    <head>
      <meta charset="UTF-8">
      <style>
        body {
          font-family: Arial, sans-serif;
          line-height: 1.6;
          color: #333;
          margin: 0;
          padding: 20px;
        }
        .container {
          max-width: 600px;
          margin: 0 auto;
          background: #ffffff;
          padding: 30px;
          border-radius: 8px;
          box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }
        .title {
          font-size: 24px;
          font-weight: bold;
          margin-bottom: 20px;
          color: #2c3e50;
        }
        .content {
          font-size: 16px;
          margin-bottom: 20px;
        }
        .code {
          background-color: #f5f5f5;
          padding: 15px;
          border-radius: 4px;
          font-size: 18px;
          font-weight: bold;
          text-align: center;
          margin: 20px 0;
        }
        .footer {
          margin-top: 30px;
          text-align: center;
          color: #666;
          font-size: 14px;
        }
      </style>
    </head>
    <body>
      <div class="container">
        <div class="title">员工个人码通知</div>
        <div class="content">
         您好, 您在【${brandName}】的员工个人码为：
        </div>
        <div class="code">
          ${employeeCode}
        </div>
        <div class="content">
          个人码用于点单设备登录和后台公用设备登录，请妥善保管好个人码。
        </div>
        <div class="footer">
          <div>Thanks</div>
          <div style="margin-top: 10px;">杭州当堂信息技术有限公司</div>
        </div>
      </div>
    </body>
  </html>
`;

export const employeeCodeNotificationWorkflow = workflow(
  'employee-code-notification-workflow',
  async ({ step, payload, subscriber }) => {
    const { brandName, employeeCode } = payload;

    const message = `您好，您在${brandName}的员工个人码为：${employeeCode}，个人码用于点单设备登陆和后台公用设备登陆，请妥善保管好个人码。`;

    // 发送短信通知
    await step.sms(
      'send-employee-code-sms',
      () => ({
        body: message,
      }),
      {
        skip: () => !subscriber.phone,
      },
    );

    // 发送邮件通知
    await step.email(
      'send-employee-code-email',
      () => ({
        subject: '员工个人码通知',
        body: generateEmailTemplate(brandName, employeeCode),
      }),
      {
        skip: () => !subscriber.email,
      },
    );
  },
  {
    payloadSchema,
  },
);
