import { workflow } from '@novu/framework';
import { z } from 'zod';

const payloadSchema = z.object({
  // 基本信息
  brandName: z.string().min(1).describe('品牌名称'),
  downloadUrl: z.string().url().describe('下载地址'),
  employeeCode: z.string().min(1).describe('员工个人码'),
  expirationDays: z.number().int().min(1).default(7).describe('链接有效天数'),
});

// 辅助函数：生成邀请消息内容
const generateInviteMessage = (
  brandName: string,
  downloadUrl: string,
  employeeCode: string,
): string => {
  return `${brandName}邀请您加入，请点击${downloadUrl} 去下载并登录壹向RMS应用，您的员工个人码为：${employeeCode} 请妥善保管好`;
};

// 辅助函数：生成HTML模板
const generateEmailTemplate = (
  brandName: string,
  downloadUrl: string,
  employeeCode: string,
  expirationDays = 7,
): string => `
  <!DOCTYPE html>
  <html>
    <head>
      <meta charset="UTF-8">
      <style>
        body {
          font-family: Arial, sans-serif;
          line-height: 1.6;
          color: #333;
          margin: 0;
          padding: 20px;
        }
        .container {
          max-width: 600px;
          margin: 0 auto;
          background: #ffffff;
          padding: 30px;
          border-radius: 8px;
          box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }
        .logo {
          max-width: 200px;
          display: block;
          margin: 0 auto 30px;
        }
        .title {
          font-size: 24px;
          font-weight: bold;
          text-align: center;
          margin-bottom: 30px;
          color: #2c3e50;
        }
        .content {
          margin-bottom: 25px;
          font-size: 16px;
        }
        .employee-code {
          background: #f8f9fa;
          padding: 15px;
          border-radius: 6px;
          font-size: 18px;
          font-weight: bold;
          text-align: center;
          margin: 20px 0;
          border: 1px solid #e9ecef;
        }
        .download-btn {
          display: inline-block;
          padding: 12px 24px;
          background-color: #1890ff;
          color: white !important;
          text-decoration: none;
          border-radius: 4px;
          margin: 20px 0;
          text-align: center;
          font-weight: bold;
        }
        .note {
          font-size: 14px;
          color: #666;
          margin-top: 25px;
          padding-top: 20px;
          border-top: 1px solid #eee;
        }
        .footer {
          margin-top: 40px;
          text-align: center;
          color: #666;
          font-size: 14px;
        }
      </style>
    </head>
    <body>
      <div class="container">
        <img class="logo" src="https://eshine-file.eshine.cn/60003/2025-02-07/logo-new.af63196.png" alt="logo" />
        <div class="title">
          邀请加入 ${brandName}
        </div>
        <div class="content">
          <strong>您好</strong>，${brandName}品牌邀请您去激活后台使用权限。
        </div>
        <div class="content">
          请下载并登录壹向RMS APP：
        </div>
        <div style="text-align: center;">
          <a href="${downloadUrl}" class="download-btn">
            点击下载壹向RMS APP
          </a>
        </div>
        <div class="content">
          您的员工个人码为：
          <div class="employee-code">${employeeCode}</div>
          <div style="color: #666;">个人码用于点单设备登陆和后台公用设备登陆，请妥善保管。</div>
        </div>
        <div class="note">
          注意：此链接 ${expirationDays} 天有效。
        </div>
        <div class="footer">
          <div>Thanks</div>
          <div style="margin-top: 10px;">杭州当堂信息技术有限公司</div>
        </div>
      </div>
    </body>
  </html>
`;

export const inviteUserWorkflow = workflow(
  'invite-user-workflow',
  async ({ step, payload, subscriber }) => {
    const { brandName, downloadUrl, employeeCode, expirationDays } = payload;

    await step.sms(
      'send-invite-user-sms',
      () => ({
        body: generateInviteMessage(brandName, downloadUrl, employeeCode),
      }),
      {
        skip: () => !subscriber.phone,
      },
    );

    await step.email(
      'send-invite-user-email',
      () => ({
        subject: `${brandName}邀请您加入`,
        body: generateEmailTemplate(
          brandName,
          downloadUrl,
          employeeCode,
          expirationDays,
        ),
      }),
      {
        skip: () => !subscriber.email,
      },
    );
  },
  {
    payloadSchema,
  },
);
