import { workflow } from '@novu/framework';
import { z } from 'zod';

// 定义提醒类型枚举
enum ReminderTypeEnum {
  BEFORE_EXPIRY = 'before_expiry',
  AFTER_EXPIRY = 'after_expiry',
}

const payloadSchema = z.object({
  // 基本信息
  reminderType: z.nativeEnum(ReminderTypeEnum).describe('提醒类型'),
  storeName: z.string().describe('门店名称'),
  products: z
    .array(
      z.object({
        name: z.string().describe('商品名称'),
        expiryDate: z.string().describe('到期日期'),
      }),
    )
    .optional()
    .describe('商品列表'),
  // 跳转信息
  renewalUrl: z.string().describe('续费页面URL'),
  showBanner: z.boolean().optional().describe('是否显示banner').default(true),
  bizType: z
    .string()
    .optional()
    .describe('业务类型')
    .default('subscription_renewal'),
});

// 生成商品列表HTML
const generateProductsList = (
  products: Array<{ name: string; expiryDate: string }>,
  isExpired: boolean,
): string => {
  return products
    .map(
      (product) =>
        `<li>${product.name} ${isExpired ? '已过期' : `${product.expiryDate}过期`}</li>`,
    )
    .join('\n');
};

// 生成邮件模板
const generateEmailTemplate = (
  storeName: string | undefined,
  products: Array<{ name: string; expiryDate: string }> | undefined,
  isExpired: boolean,
  renewalUrl: string,
): string => `
  <!DOCTYPE html>
  <html>
    <head>
      <meta charset="UTF-8">
      <style>
        body {
          font-family: Arial, sans-serif;
          line-height: 1.6;
          color: #333;
          margin: 0;
          padding: 20px;
        }
        .container {
          max-width: 600px;
          margin: 0 auto;
          background: #ffffff;
          padding: 30px;
          border-radius: 8px;
          box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }
        .title {
          font-size: 24px;
          font-weight: bold;
          margin-bottom: 20px;
          color: #2c3e50;
        }
        .content {
          font-size: 16px;
          margin-bottom: 20px;
        }
        .product-list {
          margin: 20px 0;
          padding-left: 20px;
        }
        .renewal-button {
          display: inline-block;
          padding: 12px 24px;
          background-color: #1890ff;
          color: white !important;
          text-decoration: none;
          border-radius: 4px;
          margin: 20px 0;
          text-align: center;
          font-weight: bold;
        }
        .footer {
          margin-top: 30px;
          text-align: center;
          color: #666;
          font-size: 14px;
        }
      </style>
    </head>
    <body>
      <div class="container">
        <div class="title">
          ${isExpired ? '授权已到期，请尽快续费' : '授权即将到期，请尽快续费'}
        </div>
        <div class="content">
          ${storeName}的订阅服务${isExpired ? '已经到期' : '即将到期'}：
        </div>
        ${
          products && products.length > 0
            ? `<ul class="product-list">
          ${generateProductsList(products, isExpired)}
        </ul>`
            : ''
        }
        <div class="content">
          为了不影响门店运营，请尽快续费。
        </div>
        <div style="text-align: center;">
          <a href="${renewalUrl}" class="renewal-button">
            去续费
          </a>
        </div>
        <div class="footer">
          <div>Thanks</div>
          <div style="margin-top: 10px;">杭州当堂信息技术有限公司</div>
        </div>
      </div>
    </body>
  </html>
`;

export const subscriptionRenewalReminderWorkflow = workflow(
  'subscription-renewal-reminder-workflow',
  async ({ step, payload, subscriber }) => {
    const {
      reminderType,
      storeName,
      products,
      renewalUrl,
      showBanner,
      bizType,
    } = payload;

    const isExpired = reminderType === ReminderTypeEnum.AFTER_EXPIRY;
    const title = isExpired
      ? '授权已到期，请尽快续费'
      : '授权即将到期，请尽快续费';
    const body = `${storeName}的订阅服务${isExpired ? '已经到期' : '即将到期'}，为了不影响门店运营，请尽快续费`;

    // 发送 App Push 通知
    await step.push('send-renewal-reminder-push', () => ({
      subject: title,
      body,
    }));

    // 发送短信通知
    await step.sms(
      'send-renewal-reminder-sms',
      () => ({
        body: `${body} ${renewalUrl} 拒收请回复R`,
      }),
      {
        skip: () => !subscriber.phone || !isExpired || !renewalUrl,
      },
    );

    // 发送邮件通知
    await step.email(
      'send-renewal-reminder-email',
      () => ({
        subject: title,
        body: renewalUrl
          ? generateEmailTemplate(storeName, products, isExpired, renewalUrl)
          : '',
      }),
      {
        skip: () => !subscriber.email || !renewalUrl,
      },
    );

    // 发送站内通知（仅HQ端）
    await step.inApp(
      'send-renewal-reminder-inapp',
      () => ({
        subject: title,
        body,
        primaryAction: {
          label: '去续费',
        },
        data: {
          renewalUrl,
          bizType,
          isExpired,
          showBanner,
        },
      }),
      {},
    );
  },
  {
    payloadSchema,
  },
);
