import { workflow } from '@novu/framework';
import { z } from 'zod';

// 定义通知范围的枚举
const NotificationScopeEnum = {
  ALL_NETWORK: 'all_network',
  SPECIFIC_BRANDS: 'specific_brands',
  SPECIFIC_STORES: 'specific_stores',
  SPECIFIC_DEVICES: 'specific_devices',
} as const;

// 定义推送方式的枚举
const NotificationChannelEnum = {
  SMS: 'sms',
  EMAIL: 'email',
  APP_PUSH: 'app_push',
  MESSAGE_CENTER: 'message_center',
  MESSAGE_CENTER_WITH_BANNER: 'message_center_with_banner',
} as const;

const payloadSchema = z.object({
  // 基本信息
  title: z.string().max(20).describe('消息标题'),
  summary: z.string().max(100).describe('消息提纲'),
  content: z.string().optional().describe('消息详情（富文本）'),

  // 通知范围
  notificationScope: z
    .enum([
      NotificationScopeEnum.ALL_NETWORK,
      NotificationScopeEnum.SPECIFIC_BRANDS,
      NotificationScopeEnum.SPECIFIC_STORES,
      NotificationScopeEnum.SPECIFIC_DEVICES,
    ])
    .describe('通知范围'),
  brandIds: z.array(z.string()).optional().describe('品牌ID列表'),
  storeIds: z.array(z.string()).optional().describe('门店ID列表'),
  deviceIds: z.array(z.string()).optional().describe('设备ID列表'),

  // 推送方式
  notificationChannels: z
    .array(
      z.enum([
        NotificationChannelEnum.SMS,
        NotificationChannelEnum.EMAIL,
        NotificationChannelEnum.APP_PUSH,
        NotificationChannelEnum.MESSAGE_CENTER,
        NotificationChannelEnum.MESSAGE_CENTER_WITH_BANNER,
      ]),
    )
    .describe('推送方式列表'),
  // 接收者信息
  recipientDeviceToken: z.string().optional().describe('接收者设备令牌'),
  employeeId: z.onumber().describe('员工ID').optional(),
});

export const systemAnnouncementWorkflow = workflow(
  'system-announcement-workflow',
  async ({ step, payload, subscriber }) => {
    // 发送站内通知（消息中心）
    await step.inApp(
      'send-system-announcement',
      () => ({
        subject: payload.title,
        body: payload.summary,
        data: {
          content: payload.content,
          employeeId: payload.employeeId,
          type: 'system_announcement',
          showBanner: payload.notificationChannels.includes(
            NotificationChannelEnum.MESSAGE_CENTER_WITH_BANNER,
          ),
        },
      }),
      {
        skip: () =>
          !payload?.notificationChannels?.includes(
            NotificationChannelEnum.MESSAGE_CENTER,
          ) &&
          !payload?.notificationChannels?.includes(
            NotificationChannelEnum.MESSAGE_CENTER_WITH_BANNER,
          ),
      },
    );

    // 发送 App Push 通知
    await step.push(
      'send-system-announcement-push',
      () => ({
        subject: payload.title,
        body: payload.summary,
      }),
      {
        skip: () =>
          !payload.recipientDeviceToken ||
          !payload?.notificationChannels?.includes(
            NotificationChannelEnum.APP_PUSH,
          ),
      },
    );

    // 发送短信通知
    await step.sms(
      'send-system-announcement-sms',
      () => ({
        body: `${payload.title}\n${payload.summary}`,
      }),
      {
        skip: () =>
          !subscriber.phone ||
          !payload?.notificationChannels?.includes(NotificationChannelEnum.SMS),
      },
    );

    // 发送邮件通知

    await step.email(
      'send-system-announcement-email',
      () => ({
        subject: payload.title,
        body: `
            <!DOCTYPE html>
            <html>
              <head>
                <meta charset="UTF-8">
                <style>
                  body {
                    font-family: Arial, sans-serif;
                    padding: 20px;
                  }
                  .title {
                    font-size: 18px;
                    font-weight: bold;
                    margin-bottom: 15px;
                  }
                  .summary {
                    margin-bottom: 20px;
                  }
                  .content {
                    margin-top: 20px;
                  }
                </style>
              </head>
              <body>
                <div class="title">${payload.title}</div>
                <div class="summary">${payload.summary}</div>
                ${payload.content ? `<div class="content">${payload.content}</div>` : ''}
              </body>
            </html>
          `,
      }),
      {
        skip: () =>
          !subscriber.email ||
          !payload?.notificationChannels?.includes(
            NotificationChannelEnum.EMAIL,
          ),
      },
    );
  },
  {
    payloadSchema,
  },
);
