import { workflow } from '@novu/framework';
import { z } from 'zod';

// 定义提醒场景枚举
enum ReminderScenarioEnum {
  NO_LOGIN_24H_NO_POS = 'no_login_24h_no_pos',
  NO_LOGIN_24H_WITH_POS = 'no_login_24h_with_pos',
  NO_LOGIN_72H_NO_POS = 'no_login_72h_no_pos',
  NO_LOGIN_72H_WITH_POS = 'no_login_72h_with_pos',
}

const payloadSchema = z.object({
  // 基本信息
  scenario: z.nativeEnum(ReminderScenarioEnum).describe('提醒场景'),
  url: z
    .string()
    .optional()
    .describe('跳转链接')
    .default('kutt.eshine.cn/rERTCR'),
});

// 定义场景消息配置
const scenarioMessages = {
  [ReminderScenarioEnum.NO_LOGIN_24H_NO_POS]: {
    title: '壹向戳了戳你',
    body: '小别1天，抽出3分钟开通POS，以后就可以看销售趋势和餐品排行榜啦。',
  },
  [ReminderScenarioEnum.NO_LOGIN_24H_WITH_POS]: {
    title: '壹向为你准备了门店经营报告，来看看',
    body: 'POS点单用着还顺手么？我们提供了"销售趋势"报表，来看看每日营收的变化吧。',
  },
  [ReminderScenarioEnum.NO_LOGIN_72H_NO_POS]: {
    title: '开店了么？',
    body: '没忘了我吧，我是壹向，真的不来用一下POS点单么？',
  },
  [ReminderScenarioEnum.NO_LOGIN_72H_WITH_POS]: {
    title: '壹向POS上可以直接发餐外卖订单哦',
    body: '在美团/饿了么开店了么？可以授权给我，这样就可以在POS上直接"发餐"。',
  },
};

export const trialPeriodReminderWorkflow = workflow(
  'trial-period-reminder-workflow',
  async ({ step, payload, subscriber }) => {
    const { scenario, url } = payload;
    const message = scenarioMessages[scenario];

    // 发送 App Push 通知
    await step.push('send-trial-period-reminder-push', () => ({
      subject: message.title,
      body: message.body,
    }));

    // 发送短信通知
    await step.sms(
      'send-trial-period-reminder-sms',
      () => ({
        body: `${message.body}打开app ${url} 拒收请回复R`,
      }),
      {
        skip: () => !subscriber.phone,
      },
    );

    // 发送邮件通知
    await step.email(
      'send-trial-period-reminder-email',
      () => ({
        subject: message.title,
        body: `
          <!DOCTYPE html>
          <html>
            <head>
              <meta charset="UTF-8">
              <style>
                body {
                  font-family: Arial, sans-serif;
                  line-height: 1.6;
                  color: #333;
                  margin: 0;
                  padding: 20px;
                }
                .container {
                  max-width: 600px;
                  margin: 0 auto;
                  background: #ffffff;
                  padding: 30px;
                  border-radius: 8px;
                  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
                }
                .title {
                  font-size: 24px;
                  font-weight: bold;
                  margin-bottom: 20px;
                  color: #2c3e50;
                }
                .content {
                  font-size: 16px;
                  margin-bottom: 20px;
                }
                .action-button {
                  display: inline-block;
                  padding: 12px 24px;
                  background-color: #1890ff;
                  color: white !important;
                  text-decoration: none;
                  border-radius: 4px;
                  margin: 20px 0;
                  text-align: center;
                  font-weight: bold;
                }
                .footer {
                  margin-top: 30px;
                  text-align: center;
                  color: #666;
                  font-size: 14px;
                }
              </style>
            </head>
            <body>
              <div class="container">
                <div class="title">${message.title}</div>
                <div class="content">${message.body}</div>
                <div style="text-align: center;">
                  <a href="${url}" class="action-button">
                    立即查看
                  </a>
                </div>
                <div class="footer">
                  <div>Thanks</div>
                  <div style="margin-top: 10px;">杭州当堂信息技术有限公司</div>
                </div>
              </div>
            </body>
          </html>
        `,
      }),
      {
        skip: () => !subscriber.email,
      },
    );
  },
  {
    payloadSchema,
  },
);
